==> tyt-element-1.0.2.tgz: package/js/fun.js <==
const fun = function() {};

fun.install = (Vue, options) => {
	Vue.prototype.tytConfirm = (opt,that) => {
        return new Promise((resolve, reject) => {
			that.$msgbox({
				title: '提示',
				type: 'warning',
				message: opt.msg,
				showInput: opt.showInput,
				inputPlaceholder: opt.inputPlaceholder,
				inputType:opt.inputType,
				inputPattern:/[\w!#$%&'*+/=?^_`{|}~-]+(?:\.[\w!#$%&'*+/=?^_`{|}~-]+)*@(?:[\w](?:[\w-]*[\w])?\.)+[\w](?:[\w-]*[\w])?/,
				inputErrorMessage: '邮箱格式不正确',
				showCancelButton: true,
				confirmButtonText: '确定',
				cancelButtonText: '取消',
				confirmButtonLoading : false,
				beforeClose: (act, instance, done) => {
		    		if (act === 'confirm') {
		    			//console.log(instance);
		    			if(opt.showInput){
		    				if(!instance.inputValue){
			    				that.$message.error(opt.inputPlaceholder);
			    				return;
			    			}
		    			}
		            	instance.confirmButtonLoading = true;
		            	instance.confirmButtonText = '操作中...';

						resolve({done:done,instance:instance});
						
		    //         	action({action:'to-examine',id:this.detailData.id}).then(res => {
		    //         		instance.confirmButtonLoading = false;
						// 	this.$message.success(res.msg);
						// 	this.detailData = res.data.data;
						// 	done();
						// })
		    		} else {
		    			done();
		    		}
		  		}
			}).then(act => {
				reject();
			}).catch(() => {
				reject();
	        });
		})
    }

    Vue.prototype.msgSuccess = (msg,that) => {
    	that.$message.success(msg);
    }
    Vue.prototype.msgError = (msg,that) => {
    	that.$message.error(msg);
    }

    //计算n年(y)或n月(M)或n日(d)前后的日期
    Vue.prototype.initDefaultDate = (n,timeUnit) => {
	    var curr_date = new Date();
	    if (timeUnit === 'd') {
	    curr_date.setDate(curr_date.getDate() + n);
	    } else if (timeUnit === 'M') {
	        curr_date.setMonth(curr_date.getMonth() + n);
	    } else if (timeUnit === 'y') {
	        curr_date.setFullYear(curr_date.getFullYear() + n);
	    }
	    var strYear = curr_date.getFullYear();
	    var strMonth = curr_date.getMonth()+1;
	    var strDay = curr_date.getDate();
	    var strHours = curr_date.getHours();
	    var strMinutes = curr_date.getMinutes();
		
		strMonth = strMonth<10?'0'+strMonth:strMonth;
		strDay =  strDay<10?'0'+strDay:strDay;
	 
	    var datastr = strYear + '-' + strMonth + '-' + strDay;
	    //var datastr = strYear + '-' + formatNumber(strMonth) + '-' + formatNumber(strDay) +' '+ formatNumber(strHours) + ':' + formatNumber(strMinutes);
	    return datastr;
	}

	Vue.prototype.trim = (str, pos = 'both') => {
		if (pos == 'both') {
			return str.replace(/^\s+|\s+$/g, "");
		} else if (pos == "left") {
			return str.replace(/^\s*/, '');
		} else if (pos == 'right') {
			return str.replace(/(\s*$)/g, "");
		} else if (pos == 'all') {
			return str.replace(/\s+/g, "");
		} else {
			return str;
		}
	}

	Vue.prototype.getTreeData = (data) => {        
        return getTreeData(data);
    }
    Vue.prototype.treeData2Single = (data) => {
        var a =treeData2Single(data);
        return a;
    }
    Vue.prototype.treeData2LevelStr = (data,v) => {        
        //var arr = treeData2Single(data);
        //console.log(123);
        //console.log(arr);
        return arr2LevelStr(data,v)
    }
    Vue.prototype.selectLists2IdStr = (data) => {        
        let idStr = "";
        for (let i = 0; i < data.length; i++) {
            idStr += data[i].id + ",";
        }
        return idStr;
    }
    Vue.prototype.getMath = (m, n) => {
        var num = Math.floor(Math.random() * (m - n) + n);
        return num;
    }
    Vue.prototype.getDate = (obj) => {
        return obj.getFullYear() + "-" + (obj.getMonth() + 1) + '-' + obj.getDate();
    }
    Vue.prototype.getNowDate = () => {
        var obj = new Date();
        return obj.getFullYear() + "-" + (obj.getMonth() + 1) + '-' + obj.getDate();
    }
    //取url其中一个参数
    Vue.prototype.getOptions = (name) => {
        var reg = new RegExp("(^|&)" + name + "=([^&]*)(&|$)");
        var url = window.location.href;
        var r = url.substr(url.indexOf("?") + 1).match(reg);
        if (r != null) return decodeURI(r[2]);
        return null;
    }
    Vue.prototype.in_array = (search, array) => {
        for (var i in array) {
            if (array[i] == search) {
                return true;
            }
        }
        return false;
    }
    Vue.prototype.listsData = (that) => {
        return {
            total: 0,
            lists: [],
            //token: 10 * Math.random(),
            show: false,
            listLoading: true,
            //auth: Vue.prototype.authJson(),
            //query: getUrlArgObject(),
        }
    };
    Vue.prototype.listsDefault = (that) => {
        return {
            total: 0,
            lists: [],
            //token: 10 * Math.random(),
            show: false,
            listLoading: true,
            //auth: Vue.prototype.authJson(),
            //query: getUrlArgObject(),
        }
    };
    Vue.prototype.listQuery = (that,limit=10) => {
        return {
            page: 1,
            limit: limit
        }
    };
    Vue.prototype.queryDefault = (that,limit=10) => {
        return {
            page: 1,
            limit: limit
        }
    };


    Vue.prototype.amountFormat = (num) => {
        // 判断传进来的数字是否为非空数字
       if (!isNaN(parseFloat(num))) {
            var reg = /\./g
            var newNum = Number(Number(num).toFixed(2)).toLocaleString()
            // 判断转换后的数字是否带有小数
            if (reg.test(newNum)) {
                var numArr = newNum.split('.')
                // 判断小数点后数字长度为1，则自动补0
                numArr[1] = numArr[1].length === 1 ? numArr[1] + '0' : numArr[1]
                return numArr.join('.')
            } else {
                // 整数直接在后面补上0.00
                return newNum + '.00'
            }

        } else {
            return ''
        }
    };

    Vue.prototype.checkMoney = (rule, value, callback) => {
        if(!value) return callback(new Error('请输入金额'));
        var exp = /(^([-]?)[1-9]([0-9]+)?(\.[0-9]{1,2})?$)|(^([-]?)(0){1}$)|(^([-]?)[0-9]\.[0-9]([0-9])?$)/;
        if(exp.test(value)) {
            callback();
        } else {
            callback(new Error('请输入正确的金额'));
        }
    };


    //生成随机字符串
    Vue.prototype.randomString = (len) => {
        len = len || 32;
    　　var $chars = 'ABCDEFGHJKMNPQRSTWXYZabcdefhijkmnprstwxyz2345678';    /****默认去掉了容易混淆的字符oOLl,9gq,Vv,Uu,I1****/
    　　var maxPos = $chars.length;
    　　var pwd = '';
    　　for (i = 0; i < len; i++) {
    　　　　pwd += $chars.charAt(Math.floor(Math.random() * maxPos));
    　　}
    　　return pwd;
    };
}


function getTreeData(data){
  for(var i=0;i<data.length;i++){
    if(data[i].children.length<1){
      // children若为空数组，则将children设为undefined
      data[i].children=undefined;
    }else {
      // children若不为空数组，则继续 递归调用 本方法
      getTreeData(data[i].children);
    }
  }
  return data;
}
function treeData2Single(data){
  var res = [];
  for(var i=0;i<data.length;i++){
    var children = data[i].children;
    delete data[i].children;
    res.push(data[i]);
    if(children){
      res = res.concat(treeData2Single(children));
    }
  } 
  return res; 
}
function arr2LevelStr(arr,v){
    for(var i=0;i<arr.length;i++){
        if(arr[i].id == v){
            let resArr = [];
            resArr.push(arr[i].name);
            if(arr[i].fid>0){
                resArr.push(arr2LevelStr(arr,arr[i].fid));
            }
            resArr.reverse();
            return resArr.join(' / ');
        }
    };
    return '';
}

function getUrlArgObject() {

    var args = new Object();
    var url = window.location.href;
    var url = url.substr(url.indexOf("?") + 1);
    var pairs = url.split("&"); //在逗号处断开
    for (var i = 0; i < pairs.length; i++) {
        var pos = pairs[i].indexOf('='); //查找name=value
        if (pos == -1) { //如果没有找到就跳过
            continue;
        }
        var argname = pairs[i].substring(0, pos); //提取name
        var value = pairs[i].substring(pos + 1); //提取value
        args[argname] = unescape(value); //存为属性
    }
    return args; //返回对象
}

export default fun;

==> tyt-element-1.0.3.tgz: package/js/fun.js <==
const fun = function() {};

fun.install = (Vue, options) => {
	Vue.prototype.tytConfirm = (opt,that) => {
        return new Promise((resolve, reject) => {
			that.$msgbox({
				title: '提示',
				type: 'warning',
				message: opt.msg,
				showInput: opt.showInput,
				inputPlaceholder: opt.inputPlaceholder,
				inputType:opt.inputType,
				inputPattern:/[\w!#$%&'*+/=?^_`{|}~-]+(?:\.[\w!#$%&'*+/=?^_`{|}~-]+)*@(?:[\w](?:[\w-]*[\w])?\.)+[\w](?:[\w-]*[\w])?/,
				inputErrorMessage: '邮箱格式不正确',
				showCancelButton: true,
				confirmButtonText: '确定',
				cancelButtonText: '取消',
				confirmButtonLoading : false,
				beforeClose: (act, instance, done) => {
		    		if (act === 'confirm') {
		    			//console.log(instance);
		    			if(opt.showInput){
		    				if(!instance.inputValue){
			    				that.$message.error(opt.inputPlaceholder);
			    				return;
			    			}
		    			}
		            	instance.confirmButtonLoading = true;
		            	instance.confirmButtonText = '操作中...';

						resolve({done:done,instance:instance});
						
		    //         	action({action:'to-examine',id:this.detailData.id}).then(res => {
		    //         		instance.confirmButtonLoading = false;
						// 	this.$message.success(res.msg);
						// 	this.detailData = res.data.data;
						// 	done();
						// })
		    		} else {
		    			done();
		    		}
		  		}
			}).then(act => {
				reject();
			}).catch(() => {
				reject();
	        });
		})
    }

    Vue.prototype.msgSuccess = (msg,that) => {
    	that.$message.success(msg);
    }
    Vue.prototype.msgError = (msg,that) => {
    	that.$message.error(msg);
    }

    //计算n年(y)或n月(M)或n日(d)前后的日期
    Vue.prototype.initDefaultDate = (n,timeUnit) => {
	    var curr_date = new Date();
	    if (timeUnit === 'd') {
	    curr_date.setDate(curr_date.getDate() + n);
	    } else if (timeUnit === 'M') {
	        curr_date.setMonth(curr_date.getMonth() + n);
	    } else if (timeUnit === 'y') {
	        curr_date.setFullYear(curr_date.getFullYear() + n);
	    }
	    var strYear = curr_date.getFullYear();
	    var strMonth = curr_date.getMonth()+1;
	    var strDay = curr_date.getDate();
	    var strHours = curr_date.getHours();
	    var strMinutes = curr_date.getMinutes();
		
		strMonth = strMonth<10?'0'+strMonth:strMonth;
		strDay =  strDay<10?'0'+strDay:strDay;
	 
	    var datastr = strYear + '-' + strMonth + '-' + strDay;
	    //var datastr = strYear + '-' + formatNumber(strMonth) + '-' + formatNumber(strDay) +' '+ formatNumber(strHours) + ':' + formatNumber(strMinutes);
	    return datastr;
	}

	Vue.prototype.trim = (str, pos = 'both') => {
		if (pos == 'both') {
			return str.replace(/^\s+|\s+$/g, "");
		} else if (pos == "left") {
			return str.replace(/^\s*/, '');
		} else if (pos == 'right') {
			return str.replace(/(\s*$)/g, "");
		} else if (pos == 'all') {
			return str.replace(/\s+/g, "");
		} else {
			return str;
		}
	}

	Vue.prototype.getTreeData = (data) => {        
        return getTreeData(data);
    }
    Vue.prototype.treeData2Single = (data) => {
        var a =treeData2Single(data);
        return a;
    }
    Vue.prototype.treeData2LevelStr = (data,v) => {        
        //var arr = treeData2Single(data);
        //console.log(123);
        //console.log(arr);
        return arr2LevelStr(data,v)
    }
    Vue.prototype.selectLists2IdStr = (data) => {        
        let idStr = "";
        for (let i = 0; i < data.length; i++) {
            idStr += data[i].id + ",";
        }
        return idStr;
    }
    Vue.prototype.getMath = (m, n) => {
        var num = Math.floor(Math.random() * (m - n) + n);
        return num;
    }
    Vue.prototype.getDate = (obj) => {
        return obj.getFullYear() + "-" + (obj.getMonth() + 1) + '-' + obj.getDate();
    }
    Vue.prototype.getNowDate = () => {
        var obj = new Date();
        return obj.getFullYear() + "-" + (obj.getMonth() + 1) + '-' + obj.getDate();
    }
    //取url其中一个参数
    Vue.prototype.getOptions = (name) => {
        var reg = new RegExp("(^|&)" + name + "=([^&]*)(&|$)");
        var url = window.location.href;
        var r = url.substr(url.indexOf("?") + 1).match(reg);
        if (r != null) return decodeURI(r[2]);
        return null;
    }
    Vue.prototype.in_array = (search, array) => {
        for (var i in array) {
            if (array[i] == search) {
                return true;
            }
        }
        return false;
    }
    Vue.prototype.listsData = (that) => {
        return {
            total: 0,
            lists: [],
            //token: 10 * Math.random(),
            show: false,
            listLoading: true,
            //auth: Vue.prototype.authJson(),
            //query: getUrlArgObject(),
        }
    };
    Vue.prototype.listsDefault = (that) => {
        return {
            total: 0,
            lists: [],
            //token: 10 * Math.random(),
            show: false,
            listLoading: true,
            //auth: Vue.prototype.authJson(),
            //query: getUrlArgObject(),
        }
    };
    Vue.prototype.listQuery = (that,limit=10) => {
        return {
            page: 1,
            limit: limit
        }
    };
    Vue.prototype.queryDefault = (that,limit=10) => {
        return {
            page: 1,
            limit: limit
        }
    };


    Vue.prototype.amountFormat = (num) => {
        // 判断传进来的数字是否为非空数字
       if (!isNaN(parseFloat(num))) {
            var reg = /\./g
            var newNum = Number(Number(num).toFixed(2)).toLocaleString()
            // 判断转换后的数字是否带有小数
            if (reg.test(newNum)) {
                var numArr = newNum.split('.')
                // 判断小数点后数字长度为1，则自动补0
                numArr[1] = numArr[1].length === 1 ? numArr[1] + '0' : numArr[1]
                return numArr.join('.')
            } else {
                // 整数直接在后面补上0.00
                return newNum + '.00'
            }

        } else {
            return ''
        }
    };

    Vue.prototype.checkMoney = (rule, value, callback) => {
        if(!value) return callback(new Error('请输入金额'));
        var exp = /(^([-]?)[1-9]([0-9]+)?(\.[0-9]{1,2})?$)|(^([-]?)(0){1}$)|(^([-]?)[0-9]\.[0-9]([0-9])?$)/;
        if(exp.test(value)) {
            callback();
        } else {
            callback(new Error('请输入正确的金额'));
        }
    };


    //生成随机字符串
    Vue.prototype.randomString = (len) => {
        len = len || 32;
    　　var $chars = 'ABCDEFGHJKMNPQRSTWXYZabcdefhijkmnprstwxyz2345678';    /****默认去掉了容易混淆的字符oOLl,9gq,Vv,Uu,I1****/
    　　var maxPos = $chars.length;
    　　var pwd = '';
    　　for (let i = 0; i < len; i++) {
    　　　　pwd += $chars.charAt(Math.floor(Math.random() * maxPos));
    　　}
    　　return pwd;
    };
}


function getTreeData(data){
  for(var i=0;i<data.length;i++){
    if(data[i].children.length<1){
      // children若为空数组，则将children设为undefined
      data[i].children=undefined;
    }else {
      // children若不为空数组，则继续 递归调用 本方法
      getTreeData(data[i].children);
    }
  }
  return data;
}
function treeData2Single(data){
  var res = [];
  for(var i=0;i<data.length;i++){
    var children = data[i].children;
    delete data[i].children;
    res.push(data[i]);
    if(children){
      res = res.concat(treeData2Single(children));
    }
  } 
  return res; 
}
function arr2LevelStr(arr,v){
    for(var i=0;i<arr.length;i++){
        if(arr[i].id == v){
            let resArr = [];
            resArr.push(arr[i].name);
            if(arr[i].fid>0){
                resArr.push(arr2LevelStr(arr,arr[i].fid));
            }
            resArr.reverse();
            return resArr.join(' / ');
        }
    };
    return '';
}

function getUrlArgObject() {

    var args = new Object();
    var url = window.location.href;
    var url = url.substr(url.indexOf("?") + 1);
    var pairs = url.split("&"); //在逗号处断开
    for (var i = 0; i < pairs.length; i++) {
        var pos = pairs[i].indexOf('='); //查找name=value
        if (pos == -1) { //如果没有找到就跳过
            continue;
        }
        var argname = pairs[i].substring(0, pos); //提取name
        var value = pairs[i].substring(pos + 1); //提取value
        args[argname] = unescape(value); //存为属性
    }
    return args; //返回对象
}

export default fun;
